from setuptools import setup, find_packages

setup(
    name='RetrieverVectorDB',
    version='0.4',
    description='A simple Python library for retreiving documents from vectorDB.',
    author='Nitya Shah',
    packages=find_packages(),
)